library("rms")
severity_clean_bootstrap = severity_clean_focal_and_aura[severity_clean_focal_and_aura$ilae_sz_type!="nan",]
# Bootsrapping seizure duration
# Remove any seizures with missing information for seizure duration
severity_mark = severity_clean_bootstrap[!is.na(severity_clean_bootstrap$duration),]
# # Remove these observations of zero from the model
# severity_mark = severity_mark[severity_mark[,mark]>0,]
# Remove outlier seizures
outliers = boxplot(severity_mark$duration,plot=FALSE)
severity_mark = severity_mark[which(!severity_mark$duration %in% outliers$out),]

# Isolate the information we need to create the models
ilae = ifelse(severity_mark$ilae_sz_type == severity_mark$ilae_sz_type[1],1,0)
marker = severity_mark$duration
pat = factor(severity_mark$patient_id)
model_rp = glmer(ilae~(1|pat), family='binomial')
model_ri = glmer(ilae~marker+(1|pat), family='binomial')
model_ris= glmer(ilae~scale(marker) +(scale(marker)|pat), family='binomial',
                                    control=glmerControl(optimizer="Nelder_Mead",optCtrl=list(maxfun=2e4)))


# Function for bootstapping seizure duration
n_rep = 1000
auc_tab = matrix(nrow = n_rep*10, ncol = 4)
colnames(auc_tab) = c("RP","FM", "RI", "RIS")

set.seed(1)
rand_seed = sample(1:4000, 2000, replace = FALSE)
for(rep in 1:n_rep){
  set.seed(rand_seed[rep])
  resampled_table = data.frame(matrix(ncol = ncol(data), nrow = 0))
  colnames(resampled_table) = colnames(data)
  sz_type = c("focal", "subclin")
  bootsrap_marker = "duration"
  data = severity_clean_focal_and_aura
  patients = unique(data$patient_id)
  # We need to maintain the sample size and the number of each seizure type
  for(pat in 1:length(patients)){
    pat_data = data[data$patient_id == patients[pat],]
    for(sz in 1:2){
      # Locate rows of the data table with seizure type
      type = pat_data[pat_data$ilae_sz_type == sz_type[sz],]
      # Draw with replacement
      samp = sample(1:nrow(type), nrow(type),replace = TRUE)
      type_resampled = type[samp,]
      resampled_table = rbind(resampled_table, type_resampled)
    }
  }
  
  across_dur = assess_models(resampled_table, "duration", c("focal", "subclin"))
  aucs = across_dur[[2]]
  auc_tab[rep,] = as.numeric(aucs)
}

#########
ri_ris_tab = test
rep = 1000
num_rows = 0
while(num_rows<1000){
  rep = rep+1
  set.seed(rand_seed[rep])
  resampled_table = data.frame(matrix(ncol = ncol(data), nrow = 0))
  colnames(resampled_table) = colnames(data)
  sz_type = c("focal", "subclin")
  bootsrap_marker = "duration"
  data = severity_clean_focal_and_aura
  patients = unique(data$patient_id)
  # We need to maintain the sample size and the number of each seizure type
  for(pat in 1:length(patients)){
    pat_data = data[data$patient_id == patients[pat],]
    for(sz in 1:2){
      # Locate rows of the data table with seizure type
      type = pat_data[pat_data$ilae_sz_type == sz_type[sz],]
      # Draw with replacement
      samp = sample(1:nrow(type), nrow(type),replace = TRUE)
      type_resampled = type[samp,]
      resampled_table = rbind(resampled_table, type_resampled)
    }
  }
  # Create and assess hierarchical logistic regression models
  across_dur = assess_models(resampled_table, "duration", c("focal", "subclin"))
  aucs = across_dur[[2]]
  auc_tab[rep,] = as.numeric(aucs)
  ri_ris_tab = na.omit(auc_tab[,3:4])
  num_rows = nrow(ri_ris_tab)
  cat("\n",num_rows)
}

####


par(mfrow=c(1,2))
hist(ri_ris_tab[,1])
hist(ri_ris_tab[,2])
write.csv(ri_ris_tab,"results/auc_tab.csv")

# Finding percentile of AUC values for markers when compared to seizure duration
percentile_tab = matrix(nrow=15,ncol=2)
colnames(percentile_tab) = c("RI", "RIS")
auc_obs = AUC_focal_subclin
for(mod in 3:4){
  dist = ri_ris_tab[,mod-2]
  for(mark in 1:15){
    less_than_obs = dist < auc_obs[mark,mod] 
    percentile_tab[mark, mod-2] = sum(less_than_obs)/length(less_than_obs)
  }
}
rownames(percentile_tab) = markers[1:15]

write.csv(percentile_tab,"results/comp_duration_percentiles.csv")


auc_tab = read.csv("results/auc_tab.csv", header = TRUE)
percentile_tab = read.csv("results/comp_duration_percentiles.csv", header = TRUE)

# Focal with and without impaired awareness
auc_tab_fa = matrix(nrow = 2000, ncol = 4)
colnames(auc_tab_fa) = c("RP","FM", "RI", "RIS")
sz_type = c("focal_aware", "focal_unaware")
bootstrap_marker = "duration"
data = severity_clean
patients = unique(data$patient_id)
rep = 0
num_rows = 0
while(num_rows<1000){
  rep = rep+1
  set.seed(rand_seed[rep])
  resampled_table = data.frame(matrix(ncol = ncol(data), nrow = 0))
  colnames(resampled_table) = colnames(data)

  # We need to maintain the sample size and the number of each seizure type
  for(pat in 1:length(patients)){
    pat_data = data[data$patient_id == patients[pat],]
    for(sz in 1:2){
      # Locate rows of the data table with seizure type
      type = pat_data[pat_data$ilae_sz_type == sz_type[sz],]
      # Draw with replacement
      samp = sample(1:nrow(type), nrow(type),replace = TRUE)
      type_resampled = type[samp,]
      resampled_table = rbind(resampled_table, type_resampled)
    }
  }
  # Create and assess hierarchical logistic regression models
  across_dur = assess_models(resampled_table, "duration", c("focal_aware", "focal_unaware"))
  aucs = across_dur[[2]]
  auc_tab_fa[rep,] = as.numeric(aucs)
  ri_ris_tab_fa = na.omit(auc_tab_fa[,3:4])
  num_rows = nrow(ri_ris_tab_fa)
  cat("\n",num_rows)
}

####

par(mfrow = c(1,2))
hist(ri_ris_tab_fa[,2])
hist(ri_ris_tab_fa[,3])

# Calculate percentages
percentile_tab_fa = matrix(nrow=15,ncol=2)
colnames(percentile_tab_fa) = c("RI", "RIS")
auc_obs = AUC_focal_aura
for(mod in 3:4){
  dist = ri_ris_tab_fa[,mod-2]
  for(mark in 1:15){
    less_than_obs = dist < auc_obs[mark,mod] 
    percentile_tab_fa[mark, mod-2] = sum(less_than_obs)/length(less_than_obs)
  }
}
rownames(percentile_tab_fa) = markers[1:15]

write.csv(percentile_tab_fa,"results/comp_duration_percentiles_fa.csv")

write.csv(ri_ris_tab_fa,"results/auc_tab_fa.csv")


## If you're reloading the script and want to use the saved tables:
comp_duration_percentiles_fa = read.csv("results/comp_duration_percentiles_fa.csv",header = TRUE)
ri_ris_tab_fa = read.csv("results/auc_tab_fa.csv",header = TRUE)

