## Read in data
# Read in table with severity data
SeverityTable =  read_excel("data/severity_table.xlsx")
# Read in table with patient information
patient_info = read_excel("data/patient_meta.xlsx")
surgery_outcome =  read_excel("data/treatment_outcome.xlsx")

## Markers of severity
markers = c("top_ll", "top_energy", "top_delta", "top_theta", "top_alpha", "top_beta", "top_low_gamma",
            "top_high_gamma","prop_channels_imprint", "prop_channels_max", "time_till_max_concurrent",
            "prop_to_max", "PGES_dur", "part_suppr_dur","suppr_strength", "duration")

## Preprocess severity data
severity_clean = preprocess_severity(SeverityTable, patient_info, markers)

## Remove seizures with no activity detected (i.e. num_chan_imprint = 0)
severity_clean = severity_clean[severity_clean$prop_channels_imprint != 0,]

## Preprocess patient information
patient_info = clean_patient_data(patient_info)

# Clean surgery outcome data
surgery_outcome = clean_surgery_outcome(surgery_outcome)

# Identify columns with marker values
marker_columns = match(markers,colnames(severity_clean))

# Relabel patient IDs
relab =  relabel_pat(severity_clean, patient_info,surgery_outcome)
severity_clean = relab[[1]]
patient_info = relab[[2]]
surgery_outcome = relab[[3]]
relab_table = relab[[4]]

# Extract finalised severity table
write.csv(severity_clean, "matlab_vis/severity_clean.csv")
write.csv(severity_clean, "data/severity_clean.csv")
write.csv(relab_table, "pat_relab.csv")


# Remove data/variables no longer needed
#rm(SeverityTable)


# Create CSV of markers across patient U42's seizures for figure 4
write.csv(severity_clean[severity_clean$patient_id=="U42",match(c("ilae_sz_type",markers),colnames(severity_clean))],"matlab_vis/pat_u42_markers.csv", row.names = TRUE)

