# Look at peak markers created from preictal segments
## Read in data
preictal_markers = markers[1:8]

## Preprocess severity data
# Read in table with severity data
PreictalTable =  read_excel("data/preictal_peak_table.xlsx")

## Preprocess severity data
## Relabel patient ids
PreictalTable = PreictalTable[PreictalTable$segment_id %in% severity_clean$segment_id,]
for (pat in 1:length(unique(PreictalTable$patient_id))){
  PreictalTable[PreictalTable$patient_id == relab_table[pat,1],]$patient_id = relab_table[pat,2]
}

preictal_clean = preprocess_severity(PreictalTable, patient_info, preictal_markers)


## Across-patient validation (focal (focal + aura) vs subclinical) **Main Validation**
preictal_clean_focal_and_aura = preictal_clean
preictal_clean_focal_and_aura [preictal_clean_focal_and_aura $ilae_sz_type == 'focal_aware',]$ilae_sz_type = 'focal'
preictal_clean_focal_and_aura [preictal_clean_focal_and_aura $ilae_sz_type == 'focal_unaware',]$ilae_sz_type = 'focal'
preictal_clean_focal_and_aura [preictal_clean_focal_and_aura $ilae_sz_type == 'focal_unknown',]$ilae_sz_type = 'focal'


# Compare focal and subclinical seizures
preictal_across_focal_subclin = assess_models(preictal_clean_focal_and_aura, preictal_markers, c("focal", "subclin"))
# Table of model assessment information
preictal_models_focal_subclin = preictal_across_focal_subclin[[1]]

# Table of AUC values for all models
preictal_AUC_focal_subclin = preictal_across_focal_subclin[[2]]


## Within patient validation - Wilcoxon Rank Sum Test (focal vs subclinical)
preictal_focal_subclin = preictal_clean_focal_and_aura[preictal_clean_focal_and_aura$ilae_sz_type == "focal" | preictal_clean_focal_and_aura$ilae_sz_type == "subclin",]
# Complete Wilcoxon Rank Sum Test for each patient
cat("\n Wilcoxon rank sum test")
preictal_wilcoxon_test_output = wilcoxon_rank_sum(preictal_focal_subclin, patient_info, preictal_markers, 0, 1)
preictal_wilcoxon_r = preictal_wilcoxon_test_output[[1]]
preictal_wilcoxon_p = preictal_wilcoxon_test_output[[2]]

#preictal_wilcoxon_export = data.frame(matrix(nrow = 0, ncol = ncol(preictal_wilcoxon_test_output)))
#for(pat in 1:length(preictal_wilcoxon_test_output$patient_id)){
 # preictal_wilcoxon_export = rbind(preictal_wilcoxon_export,
 #                                  preictal_wilcoxon_test_output[preictal_wilcoxon_test_output$patient_id == wilcoxon_export$patient_id[pat],])
#}

## Within patient modulation analysis - Circular linear correlation
# Perform circular linear correlation for each patient
# Permutation test with 100 permutations for p-value
cat("\n Circular-linear correalation with permutation test (1000 permutations)")
preictal_circ_lin = circ_lin_perm(preictal_clean, preictal_markers, 1000)

# Spearman's correlation with time in EMU
cat("\n Sperman's rank correlation between markers and time in EMU")
preictal_cor_emu = corr_with_emu(preictal_clean, preictal_markers)




